summary refs log tree commit diff
path: root/include/media
diff options
context:
space:
mode:
authorTomi Valkeinen <tomi.valkeinen@ideasonboard.com>2022-08-31 16:13:27 +0200
committerMauro Carvalho Chehab <mchehab@kernel.org>2022-09-24 09:09:05 +0200
commitb7319e2bd7bd7740a405719727e6fc01be1363ef (patch)
tree98ca5b68e4fb492eb678667b81eb4e47555671cc /include/media
parent87d36eb84d4f45657bb422af36c9eed0161cd032 (diff)
downloadlinux-b7319e2bd7bd7740a405719727e6fc01be1363ef.tar.gz
media: mc: entity: Rename streaming_count -> start_count
'streaming_count' is a bit misleading name, as the count is increased
with media_pipeline_start(). Let's rename it to 'start_count' instead.

Signed-off-by: Tomi Valkeinen <tomi.valkeinen@ideasonboard.com>
Reviewed-by: Laurent Pinchart <laurent.pinchart+renesas@ideasonboard.com>
Signed-off-by: Sakari Ailus <sakari.ailus@linux.intel.com>
Signed-off-by: Mauro Carvalho Chehab <mchehab@kernel.org>
Diffstat (limited to 'include/media')
-rw-r--r--include/media/media-entity.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/media/media-entity.h b/include/media/media-entity.h
index 4a67b1dfdc69..198ea1416ddd 100644
--- a/include/media/media-entity.h
+++ b/include/media/media-entity.h
@@ -100,11 +100,11 @@ struct media_graph {
 /**
  * struct media_pipeline - Media pipeline related information
  *
  * @streaming_count:	Streaming start count - streaming stop count
  * @graph:		Media graph walk during pipeline start / stop
  */
 struct media_pipeline {
-	int streaming_count;
+	int start_count;
 	struct media_graph graph;
 };
@@ -100,11 +100,11 @@ struct media_graph {
  * struct media_pipeline - Media pipeline related information
  *
- * @streaming_count:	Streaming start count - streaming stop count
+ * @start_count:	Media pipeline start - stop count
  * @graph:		Media graph walk during pipeline start / stop
  */